summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rwxr-xr-xbin/syncqt2
-rwxr-xr-xconfigure14
-rw-r--r--demos/browser/browserapplication.cpp2
-rw-r--r--demos/browser/htmls/notfound.html4
-rw-r--r--demos/embedded/fluidlauncher/pictureflow.cpp430
-rw-r--r--demos/embedded/fluidlauncher/pictureflow.h154
-rw-r--r--demos/mediaplayer/main.cpp4
-rw-r--r--demos/qtdemo/mainwindow.cpp14
-rw-r--r--demos/qtdemo/mainwindow.h2
-rw-r--r--dist/README2
-rw-r--r--dist/changes-3.0.04
-rw-r--r--dist/changes-3.0.0-beta15
-rw-r--r--dist/changes-4.3.24
-rw-r--r--dist/changes-4.3.32
-rw-r--r--dist/changes-4.4.02
-rw-r--r--doc/src/codecs.qdoc16
-rw-r--r--doc/src/designer-manual.qdoc2
-rw-r--r--doc/src/dnd.qdoc2
-rw-r--r--doc/src/emb-porting.qdoc2
-rw-r--r--doc/src/porting4-obsoletedmechanism.qdocinc4
-rw-r--r--doc/src/qmsdev.qdoc2
-rw-r--r--doc/src/snippets/code/src_corelib_tools_qbytearray.cpp8
-rw-r--r--doc/src/snippets/code/src_gui_painting_qpainter.cpp2
-rw-r--r--doc/src/snippets/code/src_qt3support_network_q3url.cpp4
-rw-r--r--doc/src/snippets/qstring/main.cpp4
-rw-r--r--examples/opengl/hellogl/glwidget.cpp10
-rw-r--r--examples/opengl/hellogl/glwidget.h4
-rw-r--r--examples/opengl/overpainting/glwidget.cpp14
-rw-r--r--examples/opengl/overpainting/glwidget.h4
-rw-r--r--examples/opengl/samplebuffers/glwidget.cpp6
-rw-r--r--examples/tools/completer/resources/wordlist.txt1
-rw-r--r--examples/tools/customcompleter/resources/wordlist.txt1
-rw-r--r--examples/xml/dombookmarks/jennifer.xbel2
-rw-r--r--examples/xml/saxbookmarks/jennifer.xbel2
-rw-r--r--src/corelib/codecs/qtsciicodec.cpp2
-rw-r--r--src/corelib/codecs/qtsciicodec_p.h2
-rw-r--r--src/corelib/global/qglobal.h2
-rw-r--r--src/gui/itemviews/qdatawidgetmapper.cpp22
-rw-r--r--src/gui/kernel/qmotifdnd_x11.cpp2
-rw-r--r--src/gui/kernel/qwidget_mac.mm2
-rw-r--r--src/gui/text/qfontengine_p.h2
-rw-r--r--src/network/access/qftp.cpp2
-rw-r--r--src/network/ssl/qsslconfiguration.h2
-rw-r--r--src/network/ssl/qsslconfiguration_p.h2
-rw-r--r--src/plugins/codecs/jp/qeucjpcodec.h2
-rw-r--r--src/plugins/codecs/jp/qjiscodec.h2
-rw-r--r--src/plugins/codecs/jp/qjpunicode.h2
-rw-r--r--src/plugins/codecs/jp/qsjiscodec.h2
-rw-r--r--src/plugins/codecs/kr/qeuckrcodec.cpp2
-rw-r--r--src/plugins/codecs/tw/qbig5codec.h2
-rw-r--r--src/qt3support/network/q3ftp.cpp2
51 files changed, 391 insertions, 398 deletions
diff --git a/bin/syncqt b/bin/syncqt
index 589659f46f..01c519e969 100755
--- a/bin/syncqt
+++ b/bin/syncqt
@@ -1,7 +1,7 @@
#!/usr/bin/perl -w
######################################################################
#
-# Synchronizes Qt header files - internal Trolltech tool.
+# Synchronizes Qt header files - internal development tool.
#
# Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
# Contact: Nokia Corporation (qt-info@nokia.com)
diff --git a/configure b/configure
index 7b7cc1c0e2..fc87950b3b 100755
--- a/configure
+++ b/configure
@@ -400,7 +400,7 @@ elif [ $COMMERCIAL_USER = "yes" ]; then
echo
echo "You are not licensed for Qt for Embedded Linux."
echo
- echo "Please contact sales@trolltech.com to upgrade your license"
+ echo "Please contact qt-info@nokia.com to upgrade your license"
echo "to include Qt for Embedded Linux, or install the"
echo "Qt Open Source Edition if you intend to develop free software."
exit 1
@@ -420,7 +420,7 @@ elif [ $COMMERCIAL_USER = "yes" ]; then
echo
echo "You are not licensed for the Qt/Mac platform."
echo
- echo "Please contact sales@trolltech.com to upgrade your license"
+ echo "Please contact qt-info@nokia.com to upgrade your license"
echo "to include the Qt/Mac platform."
exit 1
;;
@@ -439,7 +439,7 @@ elif [ $COMMERCIAL_USER = "yes" ]; then
echo
echo "You are not licensed for the Qt/X11 platform."
echo
- echo "Please contact sales@trolltech.com to upgrade your license to"
+ echo "Please contact qt-info@nokia.com to upgrade your license to"
echo "include the Qt/X11 platform, or install the Qt Open Source Edition"
echo "if you intend to develop free software."
exit 1
@@ -2970,7 +2970,7 @@ fi
#prefix
if [ -z "$QT_INSTALL_PREFIX" ]; then
if [ "$CFG_DEV" = "yes" ]; then
- QT_INSTALL_PREFIX="$outpath" # At Trolltech, we use sandboxed builds by default
+ QT_INSTALL_PREFIX="$outpath" # In Development, we use sandboxed builds by default
elif [ "$PLATFORM_QWS" = "yes" ]; then
QT_INSTALL_PREFIX="/usr/local/Trolltech/QtEmbedded-${QT_VERSION}"
if [ "$PLATFORM" != "$XPLATFORM" ]; then
@@ -3881,7 +3881,7 @@ elif [ "$Edition" != "OpenSource" ]; then
echo " Your support and upgrade period has expired."
echo
echo " You are no longer licensed to use this version of Qt."
- echo " Please contact sales@trolltech.com to renew your support"
+ echo " Please contact qt-info@nokia.com to renew your support"
echo " and upgrades for this license."
echo
echo "NOTICE NOTICE NOTICE NOTICE"
@@ -3899,7 +3899,7 @@ elif [ "$Edition" != "OpenSource" ]; then
echo " support, nor are you entitled to use any more recent"
echo " Qt releases."
echo
- echo " Please contact sales@trolltech.com to renew your"
+ echo " Please contact qt-info@nokia.com to renew your"
echo " support and upgrades for this license."
echo
echo "WARNING WARNING WARNING WARNING"
@@ -3914,7 +3914,7 @@ elif [ "$Edition" != "OpenSource" ]; then
echo " Your Evaluation license has expired."
echo
echo " You are no longer licensed to use this software. Please"
- echo " contact sales@trolltech.com to purchase license, or install"
+ echo " contact qt-info@nokia.com to purchase license, or install"
echo " the Qt Open Source Edition if you intend to develop free"
echo " software."
echo
diff --git a/demos/browser/browserapplication.cpp b/demos/browser/browserapplication.cpp
index 7a87b339c6..8262d22175 100644
--- a/demos/browser/browserapplication.cpp
+++ b/demos/browser/browserapplication.cpp
@@ -79,7 +79,7 @@ BrowserApplication::BrowserApplication(int &argc, char **argv)
: QApplication(argc, argv)
, m_localServer(0)
{
- QCoreApplication::setOrganizationName(QLatin1String("Trolltech"));
+ QCoreApplication::setOrganizationName(QLatin1String("Qt"));
QCoreApplication::setApplicationName(QLatin1String("demobrowser"));
QCoreApplication::setApplicationVersion(QLatin1String("0.1"));
#ifdef Q_WS_QWS
diff --git a/demos/browser/htmls/notfound.html b/demos/browser/htmls/notfound.html
index b04a9f83ff..e89845aa65 100644
--- a/demos/browser/htmls/notfound.html
+++ b/demos/browser/htmls/notfound.html
@@ -49,8 +49,8 @@ ul {
<h1>%2</h1>
<h2>When connecting to: %3.</h2>
<ul>
- <li>Check the address for errors such as <b>ww</b>.trolltech.com
- instead of <b>www</b>.trolltech.com</li>
+ <li>Check the address for errors such as <b>ww</b>.example.com
+ instead of <b>www</b>.example.com</li>
<li>If the address is correct, try checking the network
connection.</li>
<li>If your computer or network is protected by a firewall or
diff --git a/demos/embedded/fluidlauncher/pictureflow.cpp b/demos/embedded/fluidlauncher/pictureflow.cpp
index 19661d1cbb..f0fedf4bef 100644
--- a/demos/embedded/fluidlauncher/pictureflow.cpp
+++ b/demos/embedded/fluidlauncher/pictureflow.cpp
@@ -1,66 +1,67 @@
/****************************************************************************
**
-* Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies)
-* This is version of the Pictureflow animated image show widget modified by Nokia.
-*
-* $QT_BEGIN_LICENSE:LGPL$
-* No Commercial Usage
-* This file contains pre-release code and may not be distributed.
-* You may use this file in accordance with the terms and conditions
-* contained in the either Technology Preview License Agreement or the
-* Beta Release License Agreement.
-*
-* GNU Lesser General Public License Usage
-* Alternatively, this file may be used under the terms of the GNU Lesser
-* General Public License version 2.1 as published by the Free Software
-* Foundation and appearing in the file LICENSE.LGPL included in the
-* packaging of this file. Please review the following information to
-* ensure the GNU Lesser General Public License version 2.1 requirements
-* will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-*
-* In addition, as a special exception, Nokia gives you certain
-* additional rights. These rights are described in the Nokia Qt LGPL
-* Exception version 1.0, included in the file LGPL_EXCEPTION.txt in this
-* package.
-*
-* GNU General Public License Usage
-* Alternatively, this file may be used under the terms of the GNU
-* General Public License version 3.0 as published by the Free Software
-* Foundation and appearing in the file LICENSE.GPL included in the
-* packaging of this file. Please review the following information to
-* ensure the GNU General Public License version 3.0 requirements will be
-* met: http://www.gnu.org/copyleft/gpl.html.
-*
-* If you are unsure which license is appropriate for your use, please
-* contact the sales department at http://qt.nokia.com/contact.
-* $QT_END_LICENSE$
-*
-*
-* Redistribution and use in source and binary forms, with or without
-* modification, are permitted provided that the following conditions are met:
-* * Redistributions of source code must retain the above copyright
-* notice, this list of conditions and the following disclaimer.
-* * Redistributions in binary form must reproduce the above copyright
-* notice, this list of conditions and the following disclaimer in the
-* documentation and/or other materials provided with the distribution.
-* * Neither the name of the <organization> nor the
-* names of its contributors may be used to endorse or promote products
-* derived from this software without specific prior written permission.
-*
-* THIS SOFTWARE IS PROVIDED BY TROLLTECH ASA ``AS IS'' AND ANY
-* EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
-* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
-* DISCLAIMED. IN NO EVENT SHALL <copyright holder> BE LIABLE FOR ANY
-* DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
-* (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
-* LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
-* ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
-* (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
-* SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-
+** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Nokia Corporation (qt-info@nokia.com)
+**
+** This is a version of the Pictureflow animated image show widget modified by Nokia.
+**
+** $QT_BEGIN_LICENSE:LGPL$
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the either Technology Preview License Agreement or the
+** Beta Release License Agreement.
+**
+** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file. Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+**
+** In addition, as a special exception, Nokia gives you certain
+** additional rights. These rights are described in the Nokia Qt LGPL
+** Exception version 1.0, included in the file LGPL_EXCEPTION.txt in this
+** package.
+**
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3.0 as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL included in the
+** packaging of this file. Please review the following information to
+** ensure the GNU General Public License version 3.0 requirements will be
+** met: http://www.gnu.org/copyleft/gpl.html.
+**
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at http://qt.nokia.com/contact.
+** $QT_END_LICENSE$
+**
+** Redistribution and use in source and binary forms, with or without
+** modification, are permitted provided that the following conditions are met:
+** * Redistributions of source code must retain the above copyright
+** notice, this list of conditions and the following disclaimer.
+** * Redistributions in binary form must reproduce the above copyright
+** notice, this list of conditions and the following disclaimer in the
+** documentation and/or other materials provided with the distribution.
+** * Neither the name of the <organization> nor the
+** names of its contributors may be used to endorse or promote products
+** derived from this software without specific prior written permission.
+**
+** THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY
+** EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
+** WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
+** DISCLAIMED. IN NO EVENT SHALL Nokia Corporation BE LIABLE FOR ANY
+** DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
+** (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
+** LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
+** ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
+** (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
+** SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+**
****************************************************************************/
-/*
+/*
ORIGINAL COPYRIGHT HEADER
PictureFlow - animated image show widget
http://pictureflow.googlecode.com
@@ -157,134 +158,134 @@ inline PFreal floatToFixed(float val)
// warning: regenerate the table if IANGLE_MAX and PFREAL_SHIFT are changed!
static const PFreal sinTable[IANGLE_MAX] = {
- 3, 9, 15, 21, 28, 34, 40, 47,
- 53, 59, 65, 72, 78, 84, 90, 97,
- 103, 109, 115, 122, 128, 134, 140, 147,
- 153, 159, 165, 171, 178, 184, 190, 196,
- 202, 209, 215, 221, 227, 233, 239, 245,
- 251, 257, 264, 270, 276, 282, 288, 294,
- 300, 306, 312, 318, 324, 330, 336, 342,
- 347, 353, 359, 365, 371, 377, 383, 388,
- 394, 400, 406, 412, 417, 423, 429, 434,
- 440, 446, 451, 457, 463, 468, 474, 479,
- 485, 491, 496, 501, 507, 512, 518, 523,
- 529, 534, 539, 545, 550, 555, 561, 566,
- 571, 576, 581, 587, 592, 597, 602, 607,
- 612, 617, 622, 627, 632, 637, 642, 647,
- 652, 656, 661, 666, 671, 675, 680, 685,
- 690, 694, 699, 703, 708, 712, 717, 721,
- 726, 730, 735, 739, 743, 748, 752, 756,
- 760, 765, 769, 773, 777, 781, 785, 789,
- 793, 797, 801, 805, 809, 813, 816, 820,
- 824, 828, 831, 835, 839, 842, 846, 849,
- 853, 856, 860, 863, 866, 870, 873, 876,
- 879, 883, 886, 889, 892, 895, 898, 901,
- 904, 907, 910, 913, 916, 918, 921, 924,
- 927, 929, 932, 934, 937, 939, 942, 944,
- 947, 949, 951, 954, 956, 958, 960, 963,
- 965, 967, 969, 971, 973, 975, 977, 978,
- 980, 982, 984, 986, 987, 989, 990, 992,
- 994, 995, 997, 998, 999, 1001, 1002, 1003,
- 1004, 1006, 1007, 1008, 1009, 1010, 1011, 1012,
- 1013, 1014, 1015, 1015, 1016, 1017, 1018, 1018,
- 1019, 1019, 1020, 1020, 1021, 1021, 1022, 1022,
- 1022, 1023, 1023, 1023, 1023, 1023, 1023, 1023,
- 1023, 1023, 1023, 1023, 1023, 1023, 1023, 1022,
- 1022, 1022, 1021, 1021, 1020, 1020, 1019, 1019,
- 1018, 1018, 1017, 1016, 1015, 1015, 1014, 1013,
- 1012, 1011, 1010, 1009, 1008, 1007, 1006, 1004,
- 1003, 1002, 1001, 999, 998, 997, 995, 994,
- 992, 990, 989, 987, 986, 984, 982, 980,
- 978, 977, 975, 973, 971, 969, 967, 965,
- 963, 960, 958, 956, 954, 951, 949, 947,
- 944, 942, 939, 937, 934, 932, 929, 927,
- 924, 921, 918, 916, 913, 910, 907, 904,
- 901, 898, 895, 892, 889, 886, 883, 879,
- 876, 873, 870, 866, 863, 860, 856, 853,
- 849, 846, 842, 839, 835, 831, 828, 824,
- 820, 816, 813, 809, 805, 801, 797, 793,
- 789, 785, 781, 777, 773, 769, 765, 760,
- 756, 752, 748, 743, 739, 735, 730, 726,
- 721, 717, 712, 708, 703, 699, 694, 690,
- 685, 680, 675, 671, 666, 661, 656, 652,
- 647, 642, 637, 632, 627, 622, 617, 612,
- 607, 602, 597, 592, 587, 581, 576, 571,
- 566, 561, 555, 550, 545, 539, 534, 529,
- 523, 518, 512, 507, 501, 496, 491, 485,
- 479, 474, 468, 463, 457, 451, 446, 440,
- 434, 429, 423, 417, 412, 406, 400, 394,
- 388, 383, 377, 371, 365, 359, 353, 347,
- 342, 336, 330, 324, 318, 312, 306, 300,
- 294, 288, 282, 276, 270, 264, 257, 251,
- 245, 239, 233, 227, 221, 215, 209, 202,
- 196, 190, 184, 178, 171, 165, 159, 153,
- 147, 140, 134, 128, 122, 115, 109, 103,
- 97, 90, 84, 78, 72, 65, 59, 53,
- 47, 40, 34, 28, 21, 15, 9, 3,
- -4, -10, -16, -22, -29, -35, -41, -48,
- -54, -60, -66, -73, -79, -85, -91, -98,
- -104, -110, -116, -123, -129, -135, -141, -148,
- -154, -160, -166, -172, -179, -185, -191, -197,
- -203, -210, -216, -222, -228, -234, -240, -246,
- -252, -258, -265, -271, -277, -283, -289, -295,
- -301, -307, -313, -319, -325, -331, -337, -343,
- -348, -354, -360, -366, -372, -378, -384, -389,
- -395, -401, -407, -413, -418, -424, -430, -435,
- -441, -447, -452, -458, -464, -469, -475, -480,
- -486, -492, -497, -502, -508, -513, -519, -524,
- -530, -535, -540, -546, -551, -556, -562, -567,
- -572, -577, -582, -588, -593, -598, -603, -608,
- -613, -618, -623, -628, -633, -638, -643, -648,
- -653, -657, -662, -667, -672, -676, -681, -686,
- -691, -695, -700, -704, -709, -713, -718, -722,
- -727, -731, -736, -740, -744, -749, -753, -757,
- -761, -766, -770, -774, -778, -782, -786, -790,
- -794, -798, -802, -806, -810, -814, -817, -821,
- -825, -829, -832, -836, -840, -843, -847, -850,
- -854, -857, -861, -864, -867, -871, -874, -877,
- -880, -884, -887, -890, -893, -896, -899, -902,
- -905, -908, -911, -914, -917, -919, -922, -925,
- -928, -930, -933, -935, -938, -940, -943, -945,
- -948, -950, -952, -955, -957, -959, -961, -964,
- -966, -968, -970, -972, -974, -976, -978, -979,
- -981, -983, -985, -987, -988, -990, -991, -993,
- -995, -996, -998, -999, -1000, -1002, -1003, -1004,
- -1005, -1007, -1008, -1009, -1010, -1011, -1012, -1013,
- -1014, -1015, -1016, -1016, -1017, -1018, -1019, -1019,
- -1020, -1020, -1021, -1021, -1022, -1022, -1023, -1023,
- -1023, -1024, -1024, -1024, -1024, -1024, -1024, -1024,
- -1024, -1024, -1024, -1024, -1024, -1024, -1024, -1023,
- -1023, -1023, -1022, -1022, -1021, -1021, -1020, -1020,
- -1019, -1019, -1018, -1017, -1016, -1016, -1015, -1014,
- -1013, -1012, -1011, -1010, -1009, -1008, -1007, -1005,
- -1004, -1003, -1002, -1000, -999, -998, -996, -995,
- -993, -991, -990, -988, -987, -985, -983, -981,
- -979, -978, -976, -974, -972, -970, -968, -966,
- -964, -961, -959, -957, -955, -952, -950, -948,
- -945, -943, -940, -938, -935, -933, -930, -928,
- -925, -922, -919, -917, -914, -911, -908, -905,
- -902, -899, -896, -893, -890, -887, -884, -880,
- -877, -874, -871, -867, -864, -861, -857, -854,
- -850, -847, -843, -840, -836, -832, -829, -825,
- -821, -817, -814, -810, -806, -802, -798, -794,
- -790, -786, -782, -778, -774, -770, -766, -761,
- -757, -753, -749, -744, -740, -736, -731, -727,
- -722, -718, -713, -709, -704, -700, -695, -691,
- -686, -681, -676, -672, -667, -662, -657, -653,
- -648, -643, -638, -633, -628, -623, -618, -613,
- -608, -603, -598, -593, -588, -582, -577, -572,
- -567, -562, -556, -551, -546, -540, -535, -530,
- -524, -519, -513, -508, -502, -497, -492, -486,
- -480, -475, -469, -464, -458, -452, -447, -441,
- -435, -430, -424, -418, -413, -407, -401, -395,
- -389, -384, -378, -372, -366, -360, -354, -348,
- -343, -337, -331, -325, -319, -313, -307, -301,
- -295, -289, -283, -277, -271, -265, -258, -252,
- -246, -240, -234, -228, -222, -216, -210, -203,
- -197, -191, -185, -179, -172, -166, -160, -154,
- -148, -141, -135, -129, -123, -116, -110, -104,
- -98, -91, -85, -79, -73, -66, -60, -54,
- -48, -41, -35, -29, -22, -16, -10, -4
+ 3, 9, 15, 21, 28, 34, 40, 47,
+ 53, 59, 65, 72, 78, 84, 90, 97,
+ 103, 109, 115, 122, 128, 134, 140, 147,
+ 153, 159, 165, 171, 178, 184, 190, 196,
+ 202, 209, 215, 221, 227, 233, 239, 245,
+ 251, 257, 264, 270, 276, 282, 288, 294,
+ 300, 306, 312, 318, 324, 330, 336, 342,
+ 347, 353, 359, 365, 371, 377, 383, 388,
+ 394, 400, 406, 412, 417, 423, 429, 434,
+ 440, 446, 451, 457, 463, 468, 474, 479,
+ 485, 491, 496, 501, 507, 512, 518, 523,
+ 529, 534, 539, 545, 550, 555, 561, 566,
+ 571, 576, 581, 587, 592, 597, 602, 607,
+ 612, 617, 622, 627, 632, 637, 642, 647,
+ 652, 656, 661, 666, 671, 675, 680, 685,
+ 690, 694, 699, 703, 708, 712, 717, 721,
+ 726, 730, 735, 739, 743, 748, 752, 756,
+ 760, 765, 769, 773, 777, 781, 785, 789,
+ 793, 797, 801, 805, 809, 813, 816, 820,
+ 824, 828, 831, 835, 839, 842, 846, 849,
+ 853, 856, 860, 863, 866, 870, 873, 876,
+ 879, 883, 886, 889, 892, 895, 898, 901,
+ 904, 907, 910, 913, 916, 918, 921, 924,
+ 927, 929, 932, 934, 937, 939, 942, 944,
+ 947, 949, 951, 954, 956, 958, 960, 963,
+ 965, 967, 969, 971, 973, 975, 977, 978,
+ 980, 982, 984, 986, 987, 989, 990, 992,
+ 994, 995, 997, 998, 999, 1001, 1002, 1003,
+ 1004, 1006, 1007, 1008, 1009, 1010, 1011, 1012,
+ 1013, 1014, 1015, 1015, 1016, 1017, 1018, 1018,
+ 1019, 1019, 1020, 1020, 1021, 1021, 1022, 1022,
+ 1022, 1023, 1023, 1023, 1023, 1023, 1023, 1023,
+ 1023, 1023, 1023, 1023, 1023, 1023, 1023, 1022,
+ 1022, 1022, 1021, 1021, 1020, 1020, 1019, 1019,
+ 1018, 1018, 1017, 1016, 1015, 1015, 1014, 1013,
+ 1012, 1011, 1010, 1009, 1008, 1007, 1006, 1004,
+ 1003, 1002, 1001, 999, 998, 997, 995, 994,
+ 992, 990, 989, 987, 986, 984, 982, 980,
+ 978, 977, 975, 973, 971, 969, 967, 965,
+ 963, 960, 958, 956, 954, 951, 949, 947,
+ 944, 942, 939, 937, 934, 932, 929, 927,
+ 924, 921, 918, 916, 913, 910, 907, 904,
+ 901, 898, 895, 892, 889, 886, 883, 879,
+ 876, 873, 870, 866, 863, 860, 856, 853,
+ 849, 846, 842, 839, 835, 831, 828, 824,
+ 820, 816, 813, 809, 805, 801, 797, 793,
+ 789, 785, 781, 777, 773, 769, 765, 760,
+ 756, 752, 748, 743, 739, 735, 730, 726,
+ 721, 717, 712, 708, 703, 699, 694, 690,
+ 685, 680, 675, 671, 666, 661, 656, 652,
+ 647, 642, 637, 632, 627, 622, 617, 612,
+ 607, 602, 597, 592, 587, 581, 576, 571,
+ 566, 561, 555, 550, 545, 539, 534, 529,
+ 523, 518, 512, 507, 501, 496, 491, 485,
+ 479, 474, 468, 463, 457, 451, 446, 440,
+ 434, 429, 423, 417, 412, 406, 400, 394,
+ 388, 383, 377, 371, 365, 359, 353, 347,
+ 342, 336, 330, 324, 318, 312, 306, 300,
+ 294, 288, 282, 276, 270, 264, 257, 251,
+ 245, 239, 233, 227, 221, 215, 209, 202,
+ 196, 190, 184, 178, 171, 165, 159, 153,
+ 147, 140, 134, 128, 122, 115, 109, 103,
+ 97, 90, 84, 78, 72, 65, 59, 53,
+ 47, 40, 34, 28, 21, 15, 9, 3,
+ -4, -10, -16, -22, -29, -35, -41, -48,
+ -54, -60, -66, -73, -79, -85, -91, -98,
+ -104, -110, -116, -123, -129, -135, -141, -148,
+ -154, -160, -166, -172, -179, -185, -191, -197,
+ -203, -210, -216, -222, -228, -234, -240, -246,
+ -252, -258, -265, -271, -277, -283, -289, -295,
+ -301, -307, -313, -319, -325, -331, -337, -343,
+ -348, -354, -360, -366, -372, -378, -384, -389,
+ -395, -401, -407, -413, -418, -424, -430, -435,
+ -441, -447, -452, -458, -464, -469, -475, -480,
+ -486, -492, -497, -502, -508, -513, -519, -524,
+ -530, -535, -540, -546, -551, -556, -562, -567,
+ -572, -577, -582, -588, -593, -598, -603, -608,
+ -613, -618, -623, -628, -633, -638, -643, -648,
+ -653, -657, -662, -667, -672, -676, -681, -686,
+ -691, -695, -700, -704, -709, -713, -718, -722,
+ -727, -731, -736, -740, -744, -749, -753, -757,
+ -761, -766, -770, -774, -778, -782, -786, -790,
+ -794, -798, -802, -806, -810, -814, -817, -821,
+ -825, -829, -832, -836, -840, -843, -847, -850,
+ -854, -857, -861, -864, -867, -871, -874, -877,
+ -880, -884, -887, -890, -893, -896, -899, -902,
+ -905, -908, -911, -914, -917, -919, -922, -925,
+ -928, -930, -933, -935, -938, -940, -943, -945,
+ -948, -950, -952, -955, -957, -959, -961, -964,
+ -966, -968, -970, -972, -974, -976, -978, -979,
+ -981, -983, -985, -987, -988, -990, -991, -993,
+ -995, -996, -998, -999, -1000, -1002, -1003, -1004,
+ -1005, -1007, -1008, -1009, -1010, -1011, -1012, -1013,
+ -1014, -1015, -1016, -1016, -1017, -1018, -1019, -1019,
+ -1020, -1020, -1021, -1021, -1022, -1022, -1023, -1023,
+ -1023, -1024, -1024, -1024, -1024, -1024, -1024, -1024,
+ -1024, -1024, -1024, -1024, -1024, -1024, -1024, -1023,
+ -1023, -1023, -1022, -1022, -1021, -1021, -1020, -1020,
+ -1019, -1019, -1018, -1017, -1016, -1016, -1015, -1014,
+ -1013, -1012, -1011, -1010, -1009, -1008, -1007, -1005,
+ -1004, -1003, -1002, -1000, -999, -998, -996, -995,
+ -993, -991, -990, -988, -987, -985, -983, -981,
+ -979, -978, -976, -974, -972, -970, -968, -966,
+ -964, -961, -959, -957, -955, -952, -950, -948,
+ -945, -943, -940, -938, -935, -933, -930, -928,
+ -925, -922, -919, -917, -914, -911, -908, -905,
+ -902, -899, -896, -893, -890, -887, -884, -880,
+ -877, -874, -871, -867, -864, -861, -857, -854,
+ -850, -847, -843, -840, -836, -832, -829, -825,
+ -821, -817, -814, -810, -806, -802, -798, -794,
+ -790, -786, -782, -778, -774, -770, -766, -761,
+ -757, -753, -749, -744, -740, -736, -731, -727,
+ -722, -718, -713, -709, -704, -700, -695, -691,
+ -686, -681, -676, -672, -667, -662, -657, -653,
+ -648, -643, -638, -633, -628, -623, -618, -613,
+ -608, -603, -598, -593, -588, -582, -577, -572,
+ -567, -562, -556, -551, -546, -540, -535, -530,
+ -524, -519, -513, -508, -502, -497, -492, -486,
+ -480, -475, -469, -464, -458, -452, -447, -441,
+ -435, -430, -424, -418, -413, -407, -401, -395,
+ -389, -384, -378, -372, -366, -360, -354, -348,
+ -343, -337, -331, -325, -319, -313, -307, -301,
+ -295, -289, -283, -277, -271, -265, -258, -252,
+ -246, -240, -234, -228, -222, -216, -210, -203,
+ -197, -191, -185, -179, -172, -166, -160, -154,
+ -148, -141, -135, -129, -123, -116, -110, -104,
+ -98, -91, -85, -79, -73, -66, -60, -54,
+ -48, -41, -35, -29, -22, -16, -10, -4
};
// this is the program the generate the above table
@@ -327,7 +328,7 @@ inline PFreal fsin(int iangle)
while(iangle < 0)
iangle += IANGLE_MAX;
return sinTable[iangle & IANGLE_MASK];
-}
+}
inline PFreal fcos(int iangle)
{
@@ -443,7 +444,7 @@ PictureFlowPrivate::PictureFlowPrivate(PictureFlow* w)
triggerTimer.setSingleShot(true);
triggerTimer.setInterval(0);
QObject::connect(&triggerTimer, SIGNAL(timeout()), widget, SLOT(render()));
-
+
recalc(200, 200);
resetSlides();
}
@@ -502,7 +503,7 @@ void PictureFlowPrivate::setSlide(int index, const QImage& image)
slideImages[index] = image;
surfaceCache.remove(index);
triggerRender();
- }
+ }
}
int PictureFlowPrivate::getTarget() const
@@ -513,7 +514,7 @@ int PictureFlowPrivate::getTarget() const
int PictureFlowPrivate::currentSlide() const
{
return centerIndex;
-}
+}
void PictureFlowPrivate::setCurrentSlide(int index)
{
@@ -622,7 +623,7 @@ static QImage prepareSurface(QImage img, int w, int h)
int hofs = h / 3;
// offscreen buffer: black is sweet
- QImage result(hs, w, QImage::Format_RGB16);
+ QImage result(hs, w, QImage::Format_RGB16);
result.fill(0);
// transpose the image, this is to speed-up the rendering
@@ -699,7 +700,7 @@ QImage* PictureFlowPrivate::surface(int slideIndex)
}
-// Schedules rendering the slides. Call this function to avoid immediate
+// Schedules rendering the slides. Call this function to avoid immediate
// render and thus cause less flicker.
void PictureFlowPrivate::triggerRender()
{
@@ -727,7 +728,7 @@ void PictureFlowPrivate::render()
QRect rs = renderSlide(leftSlides[index], alpha, 0, c1-1);
if(!rs.isEmpty())
c1 = rs.left();
- }
+ }
for(int index = 0; index < nright-1; index++)
{
int alpha = (index < nright-2) ? 256 : 128;
@@ -769,7 +770,7 @@ void PictureFlowPrivate::render()
c1 = rs.left();
alpha = (step > 0) ? 256-fade/2 : 256;
- }
+ }
for(int index = 0; index < nright; index++)
{
int alpha = (index < nright-2) ? 256 : 128;
@@ -784,8 +785,6 @@ void PictureFlowPrivate::render()
c2 = rs.right();
}
-
-
QPainter painter;
painter.begin(&buffer);
@@ -803,7 +802,6 @@ void PictureFlowPrivate::render()
painter.drawText( QRect(0,0, buffer.width(), (buffer.height() - slideSize().height())/2),
Qt::AlignCenter, captions[leftTextIndex+1]);
-
painter.end();
}
}
@@ -833,8 +831,8 @@ int col1, int col2)
if(!src)
return QRect();
- QRect rect(0, 0, 0, 0);
-
+ QRect rect(0, 0, 0, 0);
+
#ifdef PICTUREFLOW_BILINEAR_FILTER
int sw = src->height() / BILINEAR_STRETCH_HOR;
int sh = src->width() / BILINEAR_STRETCH_VER;
@@ -899,10 +897,10 @@ int col1, int col2)
if(column < 0)
continue;
- rect.setRight(x);
+ rect.setRight(x);
if(!flag)
rect.setLeft(x);
- flag = true;
+ flag = true;
int y1 = h/2;
int y2 = y1+ 1;
@@ -932,7 +930,7 @@ int col1, int col2)
y2++;
pixel1 -= pixelstep;
pixel2 += pixelstep;
- }
+ }
else
while((y1 >= 0) && (y2 < h) && (p1 >= 0))
{
@@ -958,8 +956,8 @@ int col1, int col2)
y2++;
pixel1 -= pixelstep;
pixel2 += pixelstep;
- }
- }
+ }
+ }
rect.setTop(0);
rect.setBottom(h-1);
@@ -1037,7 +1035,7 @@ void PictureFlowPrivate::updateAnimation()
const int max = 2 * 65536;
int fi = slideFrame;
- fi -= (target << 16);
+ fi -= (target << 16);
if(fi < 0)
fi = -fi;
fi = qMin(fi, max);
@@ -1052,7 +1050,7 @@ void PictureFlowPrivate::updateAnimation()
int pos = slideFrame & 0xffff;
int neg = 65536 - pos;
int tick = (step < 0) ? neg : pos;
- PFreal ftick = (tick * PFREAL_ONE) >> 16;
+ PFreal ftick = (tick * PFREAL_ONE) >> 16;
// the leftmost and rightmost slide must fade away
fade = pos / 256;
@@ -1082,7 +1080,7 @@ void PictureFlowPrivate::updateAnimation()
step = 0;
fade = 256;
return;
- }
+ }
for(int i = 0; i < leftSlides.count(); i++)
{
@@ -1113,7 +1111,7 @@ void PictureFlowPrivate::updateAnimation()
leftSlides[0].angle = (pos * itilt) >> 16;
leftSlides[0].cx = -fmul(offsetX, ftick);
leftSlides[0].cy = fmul(offsetY, ftick);
- }
+ }
// must change direction ?
if(target < index) if(step > 0)
@@ -1149,7 +1147,7 @@ PictureFlow::PictureFlow(QWidget* parent): QWidget(parent)
PictureFlow::~PictureFlow()
{
delete d;
-}
+}
int PictureFlow::slideCount() const
{
@@ -1249,7 +1247,7 @@ void PictureFlow::keyPressEvent(QKeyEvent* event)
{
if(event->modifiers() == Qt::ControlModifier)
showSlide(currentSlide()-10);
- else
+ else
showPrevious();
event->accept();
return;
@@ -1299,7 +1297,7 @@ void PictureFlow::mouseMoveEvent(QMouseEvent* event)
{
speed = ((qAbs(event->pos().x()-d->previousPos.x())*1000) / d->previousPosTimestamp.elapsed())
/ (d->buffer.width() / 10);
-
+
if (speed < SPEED_LOWER_THRESHOLD)
speed = SPEED_LOWER_THRESHOLD;
else if (speed > SPEED_UPPER_LIMIT)
@@ -1307,19 +1305,17 @@ void PictureFlow::mouseMoveEvent(QMouseEvent* event)
else {
speed = SPEED_LOWER_THRESHOLD + (speed / 3);
// qDebug() << "ACCELERATION ENABLED Speed = " << speed << ", Distance = " << distanceMovedSinceLastEvent;
-
}
}
-
// qDebug() << "Speed = " << speed;
// int incr = ((event->pos().x() - d->previousPos.x())/10) * speed;
-
+
// qDebug() << "Incremented by " << incr;
int incr = (distanceMovedSinceLastEvent * speed);
-
+
//qDebug() << "(distanceMovedSinceLastEvent * speed) = " << incr;
if (incr > d->pixelsToMovePerSlide*2) {
@@ -1349,8 +1345,6 @@ void PictureFlow::mouseMoveEvent(QMouseEvent* event)
d->pixelDistanceMoved = 0;
*/
}
-
-
}
d->previousPos = event->pos();
diff --git a/demos/embedded/fluidlauncher/pictureflow.h b/demos/embedded/fluidlauncher/pictureflow.h
index 7130aeeab0..adede7850e 100644
--- a/demos/embedded/fluidlauncher/pictureflow.h
+++ b/demos/embedded/fluidlauncher/pictureflow.h
@@ -1,64 +1,66 @@
/****************************************************************************
-*
-* Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies)
-* This is version of the Pictureflow animated image show widget modified by Nokia.
-*
-* $QT_BEGIN_LICENSE:LGPL$
-* No Commercial Usage
-* This file contains pre-release code and may not be distributed.
-* You may use this file in accordance with the terms and conditions
-* contained in the either Technology Preview License Agreement or the
-* Beta Release License Agreement.
-*
-* GNU Lesser General Public License Usage
-* Alternatively, this file may be used under the terms of the GNU Lesser
-* General Public License version 2.1 as published by the Free Software
-* Foundation and appearing in the file LICENSE.LGPL included in the
-* packaging of this file. Please review the following information to
-* ensure the GNU Lesser General Public License version 2.1 requirements
-* will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-*
-* In addition, as a special exception, Nokia gives you certain
-* additional rights. These rights are described in the Nokia Qt LGPL
-* Exception version 1.0, included in the file LGPL_EXCEPTION.txt in this
-* package.
-*
-* GNU General Public License Usage
-* Alternatively, this file may be used under the terms of the GNU
-* General Public License version 3.0 as published by the Free Software
-* Foundation and appearing in the file LICENSE.GPL included in the
-* packaging of this file. Please review the following information to
-* ensure the GNU General Public License version 3.0 requirements will be
-* met: http://www.gnu.org/copyleft/gpl.html.
-*
-* If you are unsure which license is appropriate for your use, please
-* contact the sales department at http://qt.nokia.com/contact.
-* $QT_END_LICENSE$
-*
-*
-* Redistribution and use in source and binary forms, with or without
-* modification, are permitted provided that the following conditions are met:
-* * Redistributions of source code must retain the above copyright
-* notice, this list of conditions and the following disclaimer.
-* * Redistributions in binary form must reproduce the above copyright
-* notice, this list of conditions and the following disclaimer in the
-* documentation and/or other materials provided with the distribution.
-* * Neither the name of the <organization> nor the
-* names of its contributors may be used to endorse or promote products
-* derived from this software without specific prior written permission.
-*
-* THIS SOFTWARE IS PROVIDED BY TROLLTECH ASA ``AS IS'' AND ANY
-* EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
-* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
-* DISCLAIMED. IN NO EVENT SHALL <copyright holder> BE LIABLE FOR ANY
-* DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
-* (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
-* LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
-* ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
-* (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
-* SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-
+**
+** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Nokia Corporation (qt-info@nokia.com)
+**
+** This is a version of the Pictureflow animated image show widget modified by Nokia.
+**
+** $QT_BEGIN_LICENSE:LGPL$
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the either Technology Preview License Agreement or the
+** Beta Release License Agreement.
+**
+** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file. Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+**
+** In addition, as a special exception, Nokia gives you certain
+** additional rights. These rights are described in the Nokia Qt LGPL
+** Exception version 1.0, included in the file LGPL_EXCEPTION.txt in this
+** package.
+**
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3.0 as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL included in the
+** packaging of this file. Please review the following information to
+** ensure the GNU General Public License version 3.0 requirements will be
+** met: http://www.gnu.org/copyleft/gpl.html.
+**
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at http://qt.nokia.com/contact.
+** $QT_END_LICENSE$
+**
+** Redistribution and use in source and binary forms, with or without
+** modification, are permitted provided that the following conditions are met:
+** * Redistributions of source code must retain the above copyright
+** notice, this list of conditions and the following disclaimer.
+** * Redistributions in binary form must reproduce the above copyright
+** notice, this list of conditions and the following disclaimer in the
+** documentation and/or other materials provided with the distribution.
+** * Neither the name of the <organization> nor the
+** names of its contributors may be used to endorse or promote products
+** derived from this software without specific prior written permission.
+**
+** THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY
+** EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
+** WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
+** DISCLAIMED. IN NO EVENT SHALL Nokia Corporation BE LIABLE FOR ANY
+** DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
+** (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
+** LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
+** ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
+** (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
+** SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+**
****************************************************************************/
+
/*
ORIGINAL COPYRIGHT HEADER
PictureFlow - animated image show widget
@@ -93,15 +95,15 @@
class PictureFlowPrivate;
/*!
- Class PictureFlow implements an image show widget with animation effect
- like Apple's CoverFlow (in iTunes and iPod). Images are arranged in form
- of slides, one main slide is shown at the center with few slides on
- the left and right sides of the center slide. When the next or previous
- slide is brought to the front, the whole slides flow to the right or
- the right with smooth animation effect; until the new slide is finally
+ Class PictureFlow implements an image show widget with animation effect
+ like Apple's CoverFlow (in iTunes and iPod). Images are arranged in form
+ of slides, one main slide is shown at the center with few slides on
+ the left and right sides of the center slide. When the next or previous
+ slide is brought to the front, the whole slides flow to the right or
+ the right with smooth animation effect; until the new slide is finally
placed at the center.
- */
+ */
class PictureFlow : public QWidget
{
Q_OBJECT
@@ -114,7 +116,7 @@ Q_OBJECT
public:
/*!
Creates a new PictureFlow widget.
- */
+ */
PictureFlow(QWidget* parent = 0);
/*!
@@ -134,17 +136,17 @@ public:
/*!
Returns the dimension of each slide (in pixels).
- */
+ */
QSize slideSize() const;
/*!
Sets the dimension of each slide (in pixels).
- */
+ */
void setSlideSize(QSize size);
/*!
Sets the zoom factor (in percent).
- */
+ */
void setZoomFactor(int zoom);
/*!
@@ -161,13 +163,13 @@ public:
Returns QImage of specified slide.
This function will be called only whenever necessary, e.g. the 100th slide
will not be retrived when only the first few slides are visible.
- */
+ */
virtual QImage slide(int index) const;
/*!
Sets an image for specified slide. If the slide already exists,
it will be replaced.
- */
+ */
virtual void setSlide(int index, const QImage& image);
virtual void setSlideCaption(int index, QString caption);
@@ -175,20 +177,20 @@ public:
/*!
Sets a pixmap for specified slide. If the slide already exists,
it will be replaced.
- */
+ */
virtual void setSlide(int index, const QPixmap& pixmap);
/*!
Returns the index of slide currently shown in the middle of the viewport.
- */
+ */
int currentSlide() const;
public slots:
/*!
- Sets slide to be shown in the middle of the viewport. No animation
+ Sets slide to be shown in the middle of the viewport. No animation
effect will be produced, unlike using showSlide.
- */
+ */
void setCurrentSlide(int index);
/*!
diff --git a/demos/mediaplayer/main.cpp b/demos/mediaplayer/main.cpp
index 8c921fcd8a..8a6d71e681 100644
--- a/demos/mediaplayer/main.cpp
+++ b/demos/mediaplayer/main.cpp
@@ -47,9 +47,9 @@ int main (int argc, char *argv[])
Q_INIT_RESOURCE(mediaplayer);
QApplication app(argc, argv);
app.setApplicationName("Media Player");
- app.setOrganizationName("Trolltech");
+ app.setOrganizationName("Qt");
app.setQuitOnLastWindowClosed(true);
-
+
QString fileString = app.arguments().value(1);
MediaPlayer player(fileString);
player.show();
diff --git a/demos/qtdemo/mainwindow.cpp b/demos/qtdemo/mainwindow.cpp
index 7842fec3d2..5839b0c1f1 100644
--- a/demos/qtdemo/mainwindow.cpp
+++ b/demos/qtdemo/mainwindow.cpp
@@ -63,7 +63,7 @@ MainWindow::MainWindow(QWidget *parent) : QGraphicsView(parent), updateTimer(thi
this->doneAdapt = false;
this->useTimer = false;
this->updateTimer.setSingleShot(true);
- this->trolltechLogo = 0;
+ this->companyLogo = 0;
this->qtLogo = 0;
this->setupWidget();
this->setupScene();
@@ -73,7 +73,7 @@ MainWindow::MainWindow(QWidget *parent) : QGraphicsView(parent), updateTimer(thi
MainWindow::~MainWindow()
{
- delete this->trolltechLogo;
+ delete this->companyLogo;
delete this->qtLogo;
}
@@ -270,9 +270,9 @@ void MainWindow::setupSceneItems()
this->fpsLabel->setPos(Colors::stageStartX, 600 - QFontMetricsF(Colors::buttonFont()).height() - 5);
}
- this->trolltechLogo = new ImageItem(QImage(":/images/trolltech-logo.png"), 1000, 1000, this->scene, 0, true, 0.5f);
+ this->companyLogo = new ImageItem(QImage(":/images/trolltech-logo.png"), 1000, 1000, this->scene, 0, true, 0.5f);
this->qtLogo = new ImageItem(QImage(":/images/qtlogo_small.png"), 1000, 1000, this->scene, 0, true, 0.5f);
- this->trolltechLogo->setZValue(100);
+ this->companyLogo->setZValue(100);
this->qtLogo->setZValue(100);
this->pausedLabel = new DemoTextItem(QString("PAUSED"), Colors::buttonFont(), Qt::white, -1, this->scene, 0);
this->pausedLabel->setZValue(100);
@@ -456,10 +456,10 @@ void MainWindow::resizeEvent(QResizeEvent *event)
QGraphicsView::resizeEvent(event);
DemoItem::setMatrix(this->matrix());
- if (this->trolltechLogo){
+ if (this->companyLogo){
const QRectF r = this->scene->sceneRect();
- QRectF ttb = this->trolltechLogo->boundingRect();
- this->trolltechLogo->setPos(int((r.width() - ttb.width()) / 2), 595 - ttb.height());
+ QRectF ttb = this->companyLogo->boundingRect();
+ this->companyLogo->setPos(int((r.width() - ttb.width()) / 2), 595 - ttb.height());
QRectF qtb = this->qtLogo->boundingRect();
this->qtLogo->setPos(802 - qtb.width(), 0);
}
diff --git a/demos/qtdemo/mainwindow.h b/demos/qtdemo/mainwindow.h
index d8fac1fc78..634a026b49 100644
--- a/demos/qtdemo/mainwindow.h
+++ b/demos/qtdemo/mainwindow.h
@@ -98,7 +98,7 @@ private:
QTime demoStartTime;
QTime fpsTime;
QPixmap background;
- ImageItem *trolltechLogo;
+ ImageItem *companyLogo;
ImageItem *qtLogo;
bool doneAdapt;
bool useTimer;
diff --git a/dist/README b/dist/README
index 039fbc209c..d8ab95893a 100644
--- a/dist/README
+++ b/dist/README
@@ -123,7 +123,7 @@ If the problem you are reporting is only visible at run-time, try to
create a small test program that shows the problem when run. Often,
such a program can be created with some minor changes to one of the
many example programs in Qt's examples directory. Please submit the
-bug report using the Task Tracker on the Trolltech website:
+bug report using the Task Tracker on the Qt website:
http://qt.nokia.com/developer/task-tracker
diff --git a/dist/changes-3.0.0 b/dist/changes-3.0.0
index 1f6ad5bf38..819bc0c306 100644
--- a/dist/changes-3.0.0
+++ b/dist/changes-3.0.0
@@ -433,8 +433,8 @@ from one single project description. It is the C++ successor of
'tmake' which required Perl.
qmake offers additional functionallity that is difficult to reproduce
-in tmake. Trolltech uses qmake in its build system for Qt and related
-products and we have released it as free software.
+in tmake. Qt uses qmake in its build system and we have released it as
+free software.
diff --git a/dist/changes-3.0.0-beta1 b/dist/changes-3.0.0-beta1
index 2c73e7744b..e351ed1598 100644
--- a/dist/changes-3.0.0-beta1
+++ b/dist/changes-3.0.0-beta1
@@ -405,9 +405,8 @@ QMake
To ease portability we now provide the qmake utility to replace tmake.
QMake is a C++ version of tmake which offers additional functionallity
-that is difficult to reproduce in tmake. Trolltech uses qmake in its
-build system for Qt and related products and we have released it as
-free software.
+that is difficult to reproduce in tmake. Qt uses qmake in its
+build system and we have released it as free software.
Qt Functions
diff --git a/dist/changes-4.3.2 b/dist/changes-4.3.2
index 2bec4e643f..ac96a14e40 100644
--- a/dist/changes-4.3.2
+++ b/dist/changes-4.3.2
@@ -16,7 +16,7 @@ General Improvements
* This version adds the Academic Free License 3.0, Artistic License 2.0,
Zope Public License 2.1 and Eclipse Public License to the GPL
Exception for developers using the Open Source Edition of Qt.
- See the Trolltech GPL Exception Version 1.1 page in the documentation
+ See the GPL Exception Version 1.1 page in the documentation
for more information.
Tools
@@ -542,7 +542,7 @@ Mac OS X
the August Leopard pre-release (build 9A527) will not show any windows
because of a regression in the Carbon library. This has been addressed
for a future OS X release. In the meantime, if you *must* test your
- application against this Leopard build, please contact Trolltech.
+ application against this Leopard build, please contact us.
* [178551] Fixed a regression that made it impossible to deliver mouse
move events to other widgets after a double-click on a widget that was
immediately hidden as a result of the double-click event.
diff --git a/dist/changes-4.3.3 b/dist/changes-4.3.3
index 5bf6da0c08..7933426623 100644
--- a/dist/changes-4.3.3
+++ b/dist/changes-4.3.3
@@ -17,7 +17,7 @@ General Improvements
* This version adds the Common Development and Distribution License
(CDDL) to the GPL Exception for developers using the Open Source
Edition of Qt.
- See the Trolltech GPL Exception Version 1.1 page in the documentation
+ See the GPL Exception Version 1.1 page in the documentation
for more information.
* This version upgrades the Qt Commercial License to version 3.4,
the Qtopia Core Commercial License to 1.2 and the Qt Academic
diff --git a/dist/changes-4.4.0 b/dist/changes-4.4.0
index d5d5b28391..a33b510135 100644
--- a/dist/changes-4.4.0
+++ b/dist/changes-4.4.0
@@ -939,7 +939,7 @@ Third party components
requested.
- QPrintEngine
- * [193986] Fixed the Trolltech copyright date on PDF files
+ * [193986] Fixed the copyright date on PDF files
- QProcess
* [162522] QProcess now emits stateChanged() consistently for all state
diff --git a/doc/src/codecs.qdoc b/doc/src/codecs.qdoc
index fc212df6b2..7359b79d40 100644
--- a/doc/src/codecs.qdoc
+++ b/doc/src/codecs.qdoc
@@ -48,7 +48,7 @@
The code was originally contributed by Ming-Che Chuang
\<mingche@cobra.ee.ntu.edu.tw\> for the Big-5+ encoding, and was
included in Qt with the author's permission, and the grateful
- thanks of the Trolltech team. (Note: Ming-Che's code is QPL'd, as
+ thanks of the Qt team. (Note: Ming-Che's code is QPL'd, as
per an mail to qt-info@nokia.com.)
However, since Big-5+ was never formally approved, and was never
@@ -185,7 +185,7 @@
Most of the code here was written by Serika Kurusugawa,
a.k.a. Junji Takagi, and is included in Qt with the author's
- permission and the grateful thanks of the Trolltech team. Here is
+ permission and the grateful thanks of the Qt team. Here is
the copyright statement for that code:
\legalese
@@ -228,7 +228,7 @@
It was largely written by Mizi Research Inc. Here is the
copyright statement for the code as it was at the point of
- contribution. Trolltech's subsequent modifications are covered by
+ contribution. The subsequent modifications are covered by
the usual copyright for Qt.
\legalese
@@ -395,7 +395,7 @@
Most of the code here was written by Serika Kurusugawa,
a.k.a. Junji Takagi, and is included in Qt with the author's
- permission and the grateful thanks of the Trolltech team. Here is
+ permission and the grateful thanks of the Qt team. Here is
the copyright statement for that code:
\legalese
@@ -442,9 +442,9 @@
Most of the code here was written by Serika Kurusugawa, a.k.a.
Junji Takagi, and is included in Qt with the author's permission
- and the grateful thanks of the Trolltech team. Here is the
+ and the grateful thanks of the Qt team. Here is the
copyright statement for the code as it was at the point of
- contribution. Trolltech's subsequent modifications are covered by
+ contribution. The subsequent modifications are covered by
the usual copyright for Qt.
\legalese
@@ -498,8 +498,8 @@
Most of the code was written by Hans Petter Bieker and is
included in Qt with the author's permission and the grateful
- thanks of the Trolltech team. Here is the copyright statement for
- the code as it was at the point of contribution. Trolltech's
+ thanks of the Qt team. Here is the copyright statement for
+ the code as it was at the point of contribution. The
subsequent modifications are covered by the usual copyright for
Qt:
diff --git a/doc/src/designer-manual.qdoc b/doc/src/designer-manual.qdoc
index 133d7c1441..5d8587a60e 100644
--- a/doc/src/designer-manual.qdoc
+++ b/doc/src/designer-manual.qdoc
@@ -103,7 +103,7 @@
\section1 Legal Notices
Some source code in \QD is licensed under specific highly permissive
- licenses from the original authors. Trolltech gratefully acknowledges
+ licenses from the original authors. The Qt team gratefully acknowledges
these contributions to \QD and all uses of \QD should also acknowledge
these contributions and quote the following license statements in an
appendix to the documentation.
diff --git a/doc/src/dnd.qdoc b/doc/src/dnd.qdoc
index 215c039d27..661c62167b 100644
--- a/doc/src/dnd.qdoc
+++ b/doc/src/dnd.qdoc
@@ -407,7 +407,7 @@
On X11, Qt also supports drops via the Motif Drag & Drop Protocol. The
implementation incorporates some code that was originally written by
Daniel Dardailler, and adapted for Qt by Matt Koss <koss@napri.sk>
- and Trolltech. Here is the original copyright notice:
+ and Nokia. Here is the original copyright notice:
\legalese
Copyright 1996 Daniel Dardailler.
diff --git a/doc/src/emb-porting.qdoc b/doc/src/emb-porting.qdoc
index 4c746bfe44..1afd1bec77 100644
--- a/doc/src/emb-porting.qdoc
+++ b/doc/src/emb-porting.qdoc
@@ -49,7 +49,7 @@
the standard C library and some POSIX functions, but only a Linux
implementation is publically available. If you are looking for a
non-Linux commercial implementation, it is worth contacting \l
- {mailto:sales@trolltech.com}{sales@trolltech.com} to see if we can
+ {mailto:qt-info@nokia.com}{qt-info@nokia.com} to see if we can
help.
There are several issues to be aware of if you plan to do your own
diff --git a/doc/src/porting4-obsoletedmechanism.qdocinc b/doc/src/porting4-obsoletedmechanism.qdocinc
index 1594570bab..584b910395 100644
--- a/doc/src/porting4-obsoletedmechanism.qdocinc
+++ b/doc/src/porting4-obsoletedmechanism.qdocinc
@@ -1,3 +1,3 @@
If you use this mechanism in your application, please submit a
-report to the \l{Task Tracker} on the Trolltech
-website and we will try to find a satisfactory substitute.
+report to the \l{Task Tracker} on the Qt website and we will
+try to find a satisfactory substitute.
diff --git a/doc/src/qmsdev.qdoc b/doc/src/qmsdev.qdoc
index 127b5140eb..b6126a5a09 100644
--- a/doc/src/qmsdev.qdoc
+++ b/doc/src/qmsdev.qdoc
@@ -35,7 +35,7 @@
\endlist
Now the integration plugin should be installed. If this doesn't
- work, then contact Trolltech technical support giving details of
+ work, then contact Qt technical support giving details of
what went wrong.
\section1 How to uninstall the Visual Studio Integration Plugin
diff --git a/doc/src/snippets/code/src_corelib_tools_qbytearray.cpp b/doc/src/snippets/code/src_corelib_tools_qbytearray.cpp
index 870f72c8f1..c113b72603 100644
--- a/doc/src/snippets/code/src_corelib_tools_qbytearray.cpp
+++ b/doc/src/snippets/code/src_corelib_tools_qbytearray.cpp
@@ -246,16 +246,16 @@ QByteArray z = x.mid(5); // z == "pineapples"
//! [30]
-QByteArray x("TROlltECH");
+QByteArray x("Qt by NOKIA");
QByteArray y = x.toLower();
-// y == "trolltech"
+// y == "qt by nokia"
//! [30]
//! [31]
-QByteArray x("TROlltECH");
+QByteArray x("Qt by NOKIA");
QByteArray y = x.toUpper();
-// y == "TROLLTECH"
+// y == "QT BY NOKIA"
//! [31]
diff --git a/doc/src/snippets/code/src_gui_painting_qpainter.cpp b/doc/src/snippets/code/src_gui_painting_qpainter.cpp
index 611daae92e..536473ced3 100644
--- a/doc/src/snippets/code/src_gui_painting_qpainter.cpp
+++ b/doc/src/snippets/code/src_gui_painting_qpainter.cpp
@@ -173,7 +173,7 @@ painter.drawPixmap(target, image, source);
//! [17]
QPainter painter(this);
-painter.drawText(rect, Qt::AlignCenter, tr("Qt by\nTrolltech"));
+painter.drawText(rect, Qt::AlignCenter, tr("Qt by\nNokia"));
//! [17]
diff --git a/doc/src/snippets/qstring/main.cpp b/doc/src/snippets/qstring/main.cpp
index c075462c00..1179b688bd 100644
--- a/doc/src/snippets/qstring/main.cpp
+++ b/doc/src/snippets/qstring/main.cpp
@@ -801,8 +801,8 @@ void Widget::toLongLongFunction()
void Widget::toLowerFunction()
{
//! [75]
- QString str = "TROlltECH";
- str = str.toLower(); // str == "trolltech"
+ QString str = "Qt by NOKIA";
+ str = str.toLower(); // str == "qy by nokia"
//! [75]
}
diff --git a/examples/opengl/hellogl/glwidget.cpp b/examples/opengl/hellogl/glwidget.cpp
index 5722f9a0c7..877e1ca64f 100644
--- a/examples/opengl/hellogl/glwidget.cpp
+++ b/examples/opengl/hellogl/glwidget.cpp
@@ -55,8 +55,8 @@ GLWidget::GLWidget(QWidget *parent)
yRot = 0;
zRot = 0;
- trolltechGreen = QColor::fromCmykF(0.40, 0.0, 1.0, 0.0);
- trolltechPurple = QColor::fromCmykF(0.39, 0.39, 0.0, 0.0);
+ qtGreen = QColor::fromCmykF(0.40, 0.0, 1.0, 0.0);
+ qtPurple = QColor::fromCmykF(0.39, 0.39, 0.0, 0.0);
}
//! [0]
@@ -118,7 +118,7 @@ void GLWidget::setZRotation(int angle)
//! [6]
void GLWidget::initializeGL()
{
- qglClearColor(trolltechPurple.dark());
+ qglClearColor(qtPurple.dark());
object = makeObject();
glShadeModel(GL_FLAT);
glEnable(GL_DEPTH_TEST);
@@ -234,7 +234,7 @@ GLuint GLWidget::makeObject()
void GLWidget::quad(GLdouble x1, GLdouble y1, GLdouble x2, GLdouble y2,
GLdouble x3, GLdouble y3, GLdouble x4, GLdouble y4)
{
- qglColor(trolltechGreen);
+ qglColor(qtGreen);
glVertex3d(x1, y1, -0.05);
glVertex3d(x2, y2, -0.05);
@@ -249,7 +249,7 @@ void GLWidget::quad(GLdouble x1, GLdouble y1, GLdouble x2, GLdouble y2,
void GLWidget::extrude(GLdouble x1, GLdouble y1, GLdouble x2, GLdouble y2)
{
- qglColor(trolltechGreen.dark(250 + int(100 * x1)));
+ qglColor(qtGreen.dark(250 + int(100 * x1)));
glVertex3d(x1, y1, +0.05);
glVertex3d(x2, y2, +0.05);
diff --git a/examples/opengl/hellogl/glwidget.h b/examples/opengl/hellogl/glwidget.h
index be3fb356ae..1474965df3 100644
--- a/examples/opengl/hellogl/glwidget.h
+++ b/examples/opengl/hellogl/glwidget.h
@@ -91,8 +91,8 @@ private:
int yRot;
int zRot;
QPoint lastPos;
- QColor trolltechGreen;
- QColor trolltechPurple;
+ QColor qtGreen;
+ QColor qtPurple;
};
//! [3]
diff --git a/examples/opengl/overpainting/glwidget.cpp b/examples/opengl/overpainting/glwidget.cpp
index 3e4b17fb24..a6e61959cb 100644
--- a/examples/opengl/overpainting/glwidget.cpp
+++ b/examples/opengl/overpainting/glwidget.cpp
@@ -64,8 +64,8 @@ GLWidget::GLWidget(QWidget *parent)
yRot = 0;
zRot = 0;
- trolltechGreen = QColor::fromCmykF(0.40, 0.0, 1.0, 0.0);
- trolltechPurple = QColor::fromCmykF(0.39, 0.39, 0.0, 0.0);
+ qtGreen = QColor::fromCmykF(0.40, 0.0, 1.0, 0.0);
+ qtPurple = QColor::fromCmykF(0.39, 0.39, 0.0, 0.0);
animationTimer.setSingleShot(false);
connect(&animationTimer, SIGNAL(timeout()), this, SLOT(animate()));
@@ -142,7 +142,7 @@ void GLWidget::paintEvent(QPaintEvent *event)
//! [4]
//! [6]
- qglClearColor(trolltechPurple.dark());
+ qglClearColor(qtPurple.dark());
glShadeModel(GL_SMOOTH);
glEnable(GL_DEPTH_TEST);
glEnable(GL_CULL_FACE);
@@ -210,9 +210,9 @@ GLuint GLWidget::makeObject()
glEnable(GL_NORMALIZE);
glBegin(GL_QUADS);
- static GLfloat logoDiffuseColor[4] = {trolltechGreen.red()/255.0,
- trolltechGreen.green()/255.0,
- trolltechGreen.blue()/255.0, 1.0};
+ static GLfloat logoDiffuseColor[4] = {qtGreen.red()/255.0,
+ qtGreen.green()/255.0,
+ qtGreen.blue()/255.0, 1.0};
glMaterialfv(GL_FRONT, GL_DIFFUSE, logoDiffuseColor);
GLdouble x1 = +0.06;
@@ -281,7 +281,7 @@ void GLWidget::quad(GLdouble x1, GLdouble y1, GLdouble x2, GLdouble y2,
void GLWidget::extrude(GLdouble x1, GLdouble y1, GLdouble x2, GLdouble y2)
{
- qglColor(trolltechGreen.dark(250 + int(100 * x1)));
+ qglColor(qtGreen.dark(250 + int(100 * x1)));
glNormal3d((x1 + x2)/2.0, (y1 + y2)/2.0, 0.0);
glVertex3d(x1, y1, +0.05);
diff --git a/examples/opengl/overpainting/glwidget.h b/examples/opengl/overpainting/glwidget.h
index df40808591..13814a6b36 100644
--- a/examples/opengl/overpainting/glwidget.h
+++ b/examples/opengl/overpainting/glwidget.h
@@ -103,8 +103,8 @@ private:
int yRot;
int zRot;
QPoint lastPos;
- QColor trolltechGreen;
- QColor trolltechPurple;
+ QColor qtGreen;
+ QColor qtPurple;
//! [4]
QList<Bubble*> bubbles;
QTimer animationTimer;
diff --git a/examples/opengl/samplebuffers/glwidget.cpp b/examples/opengl/samplebuffers/glwidget.cpp
index 7b45856181..9a41f51965 100644
--- a/examples/opengl/samplebuffers/glwidget.cpp
+++ b/examples/opengl/samplebuffers/glwidget.cpp
@@ -106,7 +106,7 @@ void GLWidget::timerEvent(QTimerEvent *)
void GLWidget::makeObject()
{
- QColor trolltechGreen(QColor::fromCmykF(0.40, 0.0, 1.0, 0.0));
+ QColor qtGreen(QColor::fromCmykF(0.40, 0.0, 1.0, 0.0));
const double Pi = 3.14159265358979323846;
const int NumSectors = 15;
GLdouble x1 = +0.06;
@@ -134,13 +134,13 @@ void GLWidget::makeObject()
GLdouble x8 = 0.30 * sin(angle2);
GLdouble y8 = 0.30 * cos(angle2);
- qglColor(trolltechGreen);
+ qglColor(qtGreen);
quad(GL_QUADS, x5, y5, x6, y6, x7, y7, x8, y8);
qglColor(Qt::black);
quad(GL_LINE_LOOP, x5, y5, x6, y6, x7, y7, x8, y8);
}
- qglColor(trolltechGreen);
+ qglColor(qtGreen);
quad(GL_QUADS, x1, y1, x2, y2, y2, x2, y1, x1);
quad(GL_QUADS, x3, y3, x4, y4, y4, x4, y3, x3);
diff --git a/examples/tools/completer/resources/wordlist.txt b/examples/tools/completer/resources/wordlist.txt
index e598a19b59..1f56e36d47 100644
--- a/examples/tools/completer/resources/wordlist.txt
+++ b/examples/tools/completer/resources/wordlist.txt
@@ -1366,7 +1366,6 @@ transparency
transparent
travel
traveled
-Trolltech
true
try
turn
diff --git a/examples/tools/customcompleter/resources/wordlist.txt b/examples/tools/customcompleter/resources/wordlist.txt
index a5de826396..f8b581a405 100644
--- a/examples/tools/customcompleter/resources/wordlist.txt
+++ b/examples/tools/customcompleter/resources/wordlist.txt
@@ -1337,7 +1337,6 @@ transparency
transparent
travel
traveled
-Trolltech
true
try
turn
diff --git a/examples/xml/dombookmarks/jennifer.xbel b/examples/xml/dombookmarks/jennifer.xbel
index 6cfa491e82..36256fda0a 100644
--- a/examples/xml/dombookmarks/jennifer.xbel
+++ b/examples/xml/dombookmarks/jennifer.xbel
@@ -4,7 +4,7 @@
<folder folded="no">
<title>Qt Resources</title>
<folder folded="yes">
- <title>Trolltech Partners</title>
+ <title>Qt Partners</title>
<bookmark href="http://partners.trolltech.com/partners/training.html">
<title>Training Partners</title>
</bookmark>
diff --git a/examples/xml/saxbookmarks/jennifer.xbel b/examples/xml/saxbookmarks/jennifer.xbel
index cd9bece363..d6a5b41d05 100644
--- a/examples/xml/saxbookmarks/jennifer.xbel
+++ b/examples/xml/saxbookmarks/jennifer.xbel
@@ -4,7 +4,7 @@
<folder folded="no">
<title>Qt Resources</title>
<folder folded="yes">
- <title>Trolltech Partners</title>
+ <title>Qt Partners</title>
<bookmark href="http://partners.trolltech.com/partners/training.html">
<title>Training Partners</title>
</bookmark>
diff --git a/src/corelib/codecs/qtsciicodec.cpp b/src/corelib/codecs/qtsciicodec.cpp
index 81adddebc9..65367d5927 100644
--- a/src/corelib/codecs/qtsciicodec.cpp
+++ b/src/corelib/codecs/qtsciicodec.cpp
@@ -41,7 +41,7 @@
// Most of the code here was originally written by Hans Petter Bieker,
// and is included in Qt with the author's permission, and the grateful
-// thanks of the Trolltech team.
+// thanks of the Qt team.
#include "qtsciicodec_p.h"
#include "qlist.h"
diff --git a/src/corelib/codecs/qtsciicodec_p.h b/src/corelib/codecs/qtsciicodec_p.h
index 42beb44366..190d496ffe 100644
--- a/src/corelib/codecs/qtsciicodec_p.h
+++ b/src/corelib/codecs/qtsciicodec_p.h
@@ -41,7 +41,7 @@
// Most of the code here was originally written by Hans Petter Bieker,
// and is included in Qt with the author's permission, and the grateful
-// thanks of the Trolltech team.
+// thanks of the Qt team.
/*
* Copyright (C) 2000 Hans Petter Bieker. All rights reserved.
diff --git a/src/corelib/global/qglobal.h b/src/corelib/global/qglobal.h
index 7081d2f6ff..7076a1e17d 100644
--- a/src/corelib/global/qglobal.h
+++ b/src/corelib/global/qglobal.h
@@ -1292,7 +1292,7 @@ class QDataStream;
/*
No, this is not an evil backdoor. QT_BUILD_INTERNAL just exports more symbols
- for Trolltech's internal unit tests. If you want slower loading times and more
+ for Qt's internal unit tests. If you want slower loading times and more
symbols that can vanish from version to version, feel free to define QT_BUILD_INTERNAL.
*/
#if defined(QT_BUILD_INTERNAL) && defined(Q_OS_WIN) && defined(QT_MAKEDLL)
diff --git a/src/gui/itemviews/qdatawidgetmapper.cpp b/src/gui/itemviews/qdatawidgetmapper.cpp
index 8b5ba3b896..4a8db9ef94 100644
--- a/src/gui/itemviews/qdatawidgetmapper.cpp
+++ b/src/gui/itemviews/qdatawidgetmapper.cpp
@@ -278,11 +278,11 @@ void QDataWidgetMapperPrivate::_q_modelDestroyed()
Let us assume that we have an item model named \c{model} with the following contents:
\table
- \row \o 1 \o Nokia Corporation and/or its subsidiary(-ies) \o Oslo
- \row \o 2 \o Trolltech Pty \o Brisbane
- \row \o 3 \o Trolltech Inc \o Palo Alto
- \row \o 4 \o Trolltech China \o Beijing
- \row \o 5 \o Trolltech GmbH \o Berlin
+ \row \o 1 \o Qt Norway \o Oslo
+ \row \o 2 \o Qt Australia \o Brisbane
+ \row \o 3 \o Qt USA \o Palo Alto
+ \row \o 4 \o Qt China \o Beijing
+ \row \o 5 \o Qt Germany \o Berlin
\endtable
The following code will map the columns of the model to widgets called \c mySpinBox,
@@ -780,11 +780,11 @@ void QDataWidgetMapper::clearMapping()
Use Qt::Horizontal for tabular data that looks like this:
\table
- \row \o 1 \o Nokia Corporation and/or its subsidiary(-ies) \o Oslo
- \row \o 2 \o Trolltech Pty \o Brisbane
- \row \o 3 \o Trolltech Inc \o Silicon Valley
- \row \o 4 \o Trolltech China \o Beijing
- \row \o 5 \o Trolltech GmbH \o Berlin
+ \row \o 1 \o Qt Norway \o Oslo
+ \row \o 2 \o Qt Australia \o Brisbane
+ \row \o 3 \o Qt USA \o Silicon Valley
+ \row \o 4 \o Qt China \o Beijing
+ \row \o 5 \o Qt Germany \o Berlin
\endtable
If the orientation is set to Qt::Vertical, a widget is mapped to
@@ -796,7 +796,7 @@ void QDataWidgetMapper::clearMapping()
\table
\row \o 1 \o 2 \o 3 \o 4 \o 5
- \row \o Nokia Corporation and/or its subsidiary(-ies) \o Trolltech Pty \o Trolltech Inc \o Trolltech China \o Trolltech GmbH
+ \row \o Qt Norway \o Qt Australia \o Qt USA \o Qt China \o Qt Germany
\row \o Oslo \o Brisbane \o Silicon Valley \o Beijing \i Berlin
\endtable
diff --git a/src/gui/kernel/qmotifdnd_x11.cpp b/src/gui/kernel/qmotifdnd_x11.cpp
index 10c4e48d19..d180eccc43 100644
--- a/src/gui/kernel/qmotifdnd_x11.cpp
+++ b/src/gui/kernel/qmotifdnd_x11.cpp
@@ -40,7 +40,7 @@
****************************************************************************/
/* The following copyright notice pertains to the code as contributed
-to Trolltech, not to Trolltech's modifications. It is replicated
+to Qt, not to Nokia's modifications. It is replicated
in doc/dnd.doc, where the documentation system can see it. */
/* Copyright 1996 Daniel Dardailler.
diff --git a/src/gui/kernel/qwidget_mac.mm b/src/gui/kernel/qwidget_mac.mm
index 36d6ff6555..48a4bc3345 100644
--- a/src/gui/kernel/qwidget_mac.mm
+++ b/src/gui/kernel/qwidget_mac.mm
@@ -2245,7 +2245,7 @@ void QWidgetPrivate::createWindow_sys()
OSWindowRef windowRef = qt_mac_create_window(q, topExtra->wclass, wattr, data.crect);
if (windowRef == 0)
- qWarning("QWidget: Internal error: %s:%d: If you reach this error please contact Trolltech and include the\n"
+ qWarning("QWidget: Internal error: %s:%d: If you reach this error please contact Qt Support and include the\n"
" WidgetFlags used in creating the widget.", __FILE__, __LINE__);
#ifndef QT_MAC_USE_COCOA
finishCreateWindow_sys_Carbon(windowRef);
diff --git a/src/gui/text/qfontengine_p.h b/src/gui/text/qfontengine_p.h
index a6cea49293..8818e4f60c 100644
--- a/src/gui/text/qfontengine_p.h
+++ b/src/gui/text/qfontengine_p.h
@@ -107,7 +107,7 @@ public:
// Apple Mac OS types
Mac,
- // Trolltech QWS types
+ // QWS types
Freetype,
QPF1,
QPF2,
diff --git a/src/network/access/qftp.cpp b/src/network/access/qftp.cpp
index 2697f9385d..5d5c9783cc 100644
--- a/src/network/access/qftp.cpp
+++ b/src/network/access/qftp.cpp
@@ -1343,7 +1343,7 @@ int QFtpPrivate::addCommand(QFtpCommand *cmd)
Some commands, e.g. list(), emit additional signals to report
their results.
- Example: If you want to download the INSTALL file from Trolltech's
+ Example: If you want to download the INSTALL file from the Qt
FTP server, you would write this:
\snippet doc/src/snippets/code/src_network_access_qftp.cpp 1
diff --git a/src/network/ssl/qsslconfiguration.h b/src/network/ssl/qsslconfiguration.h
index 0736c66c6b..a5ed0b5ea8 100644
--- a/src/network/ssl/qsslconfiguration.h
+++ b/src/network/ssl/qsslconfiguration.h
@@ -41,7 +41,7 @@
/****************************************************************************
**
-** In addition, as a special exception, Trolltech gives permission to link
+** In addition, as a special exception, Nokia gives permission to link
** the code of its release of Qt with the OpenSSL project's "OpenSSL" library
** (or modified versions of the "OpenSSL" library that use the same license
** as the original version), and distribute the linked executables.
diff --git a/src/network/ssl/qsslconfiguration_p.h b/src/network/ssl/qsslconfiguration_p.h
index b2f059b369..52e3e9540d 100644
--- a/src/network/ssl/qsslconfiguration_p.h
+++ b/src/network/ssl/qsslconfiguration_p.h
@@ -41,7 +41,7 @@
/****************************************************************************
**
-** In addition, as a special exception, Trolltech gives permission to link
+** In addition, as a special exception, Nokia gives permission to link
** the code of its release of Qt with the OpenSSL project's "OpenSSL" library
** (or modified versions of the "OpenSSL" library that use the same license
** as the original version), and distribute the linked executables.
diff --git a/src/plugins/codecs/jp/qeucjpcodec.h b/src/plugins/codecs/jp/qeucjpcodec.h
index 11a70660a6..393d7f1ec1 100644
--- a/src/plugins/codecs/jp/qeucjpcodec.h
+++ b/src/plugins/codecs/jp/qeucjpcodec.h
@@ -41,7 +41,7 @@
// Most of the code here was originally written by Serika Kurusugawa
// a.k.a. Junji Takagi, and is included in Qt with the author's permission,
-// and the grateful thanks of the Trolltech team.
+// and the grateful thanks of the Qt team.
/*
* Copyright (C) 1999 Serika Kurusugawa, All rights reserved.
diff --git a/src/plugins/codecs/jp/qjiscodec.h b/src/plugins/codecs/jp/qjiscodec.h
index 4d58647e7f..9b95d58d5c 100644
--- a/src/plugins/codecs/jp/qjiscodec.h
+++ b/src/plugins/codecs/jp/qjiscodec.h
@@ -41,7 +41,7 @@
// Most of the code here was originally written by Serika Kurusugawa
// a.k.a. Junji Takagi, and is included in Qt with the author's permission,
-// and the grateful thanks of the Trolltech team.
+// and the grateful thanks of the Qt team.
/*
* Copyright (C) 1999 Serika Kurusugawa, All rights reserved.
diff --git a/src/plugins/codecs/jp/qjpunicode.h b/src/plugins/codecs/jp/qjpunicode.h
index eaa6a041dc..eaa76e820a 100644
--- a/src/plugins/codecs/jp/qjpunicode.h
+++ b/src/plugins/codecs/jp/qjpunicode.h
@@ -41,7 +41,7 @@
// Most of the code here was originally written by Serika Kurusugawa
// a.k.a. Junji Takagi, and is included in Qt with the author's permission,
-// and the grateful thanks of the Trolltech team.
+// and the grateful thanks of the Qt team.
/*
* Copyright (C) 1999 Serika Kurusugawa, All rights reserved.
diff --git a/src/plugins/codecs/jp/qsjiscodec.h b/src/plugins/codecs/jp/qsjiscodec.h
index 7c1fddf211..5719b93e1a 100644
--- a/src/plugins/codecs/jp/qsjiscodec.h
+++ b/src/plugins/codecs/jp/qsjiscodec.h
@@ -41,7 +41,7 @@
// Most of the code here was originally written by Serika Kurusugawa
// a.k.a. Junji Takagi, and is included in Qt with the author's permission,
-// and the grateful thanks of the Trolltech team.
+// and the grateful thanks of the Qt team.
/*
* Copyright (C) 1999 Serika Kurusugawa, All rights reserved.
diff --git a/src/plugins/codecs/kr/qeuckrcodec.cpp b/src/plugins/codecs/kr/qeuckrcodec.cpp
index 959e4fab69..48b3d9928c 100644
--- a/src/plugins/codecs/kr/qeuckrcodec.cpp
+++ b/src/plugins/codecs/kr/qeuckrcodec.cpp
@@ -40,7 +40,7 @@
****************************************************************************/
// Most of the cp949 code was originally written by Joon-Kyu Park, and is included
-// in Qt with the author's permission and the grateful thanks of the Trolltech team.
+// in Qt with the author's permission and the grateful thanks of the Qt team.
/*! \class QEucKrCodec
\reentrant
diff --git a/src/plugins/codecs/tw/qbig5codec.h b/src/plugins/codecs/tw/qbig5codec.h
index 9f0a9cc3aa..d65b44521b 100644
--- a/src/plugins/codecs/tw/qbig5codec.h
+++ b/src/plugins/codecs/tw/qbig5codec.h
@@ -41,7 +41,7 @@
// Most of the code here was originally written by Ming-Che Chuang and
// is included in Qt with the author's permission, and the grateful
-// thanks of the Trolltech team.
+// thanks of the Qt team.
#ifndef QBIG5CODEC_H
#define QBIG5CODEC_H
diff --git a/src/qt3support/network/q3ftp.cpp b/src/qt3support/network/q3ftp.cpp
index 7dd9740945..bc03368ac3 100644
--- a/src/qt3support/network/q3ftp.cpp
+++ b/src/qt3support/network/q3ftp.cpp
@@ -1144,7 +1144,7 @@ static void delete_d( const Q3Ftp* foo )
Some commands, e.g. list(), emit additional signals to report
their results.
- Example: If you want to download the INSTALL file from Trolltech's
+ Example: If you want to download the INSTALL file from the Qt
FTP server, you would write this:
\snippet doc/src/snippets/code/src_qt3support_network_q3ftp.cpp 2
diff --git a/doc/src/snippets/code/src_qt3support_network_q3url.cpp b/doc/src/snippets/code/src_qt3support_network_q3url.cpp
index 6dc9f31098..d0174a99b4 100644
--- a/doc/src/snippets/code/src_qt3support_network_q3url.cpp
+++ b/doc/src/snippets/code/src_qt3support_network_q3url.cpp
@@ -32,12 +32,12 @@ Q3Url url( "ftp://ftp.qt.nokia.com/qt/source", "file:///usr/local" );
//! [5]
QString url = http://qt.nokia.com
Q3Url::encode( url );
// url is now "http%3A//www%20trolltech%20com"
//! [5]
//! [6]
-QString url = "http%3A//www%20trolltech%20com"
+QString url = "http%3A//qt%20nokia%20com"
Q3Url::decode( url );
// url is now "http://qt.nokia.com"
//! [6]
@@ -32,12 +32,12 @@ Q3Url url( "ftp://ftp.qt.nokia.com/qt/source", "file:///usr/local" );
QString url = http://qt.nokia.com
Q3Url::encode( url );
-// url is now "http%3A//www%20trolltech%20com"
+// url is now "http%3A//qt%20nokia%20com"
//! [5]
//! [6]